﻿using System;
using System.IO;
using System.IO.IsolatedStorage;
using System.Reflection;
using System.Windows;
using Microsoft.Phone.Controls;

namespace MyMemo {
  public enum Action {None, Open, Save, Delete};

  public partial class MainPage : 
    PhoneApplicationPage {
    
    private const string TempFilename = "temp";
    public static string ApplicationName;
    public static Action MyAction = Action.None;
    private string FilenameValue;
    public string Filename { 
      get { return FilenameValue; } 
      set {
        if ((value != TempFilename) && 
          (value != "")) {
          FilenameValue = value;
          ApplicationTitle.Text = ApplicationName + 
            " - " + value;
        } else {
          ApplicationTitle.Text = ApplicationName;
        }
      } 
    }

    public MainPage() {
      InitializeComponent();
      AssemblyName an = new AssemblyName(
        Assembly.GetExecutingAssembly().FullName);
      ApplicationName = an.Name;
    }

    private void menuItemNew_Click(
      object sender, EventArgs e) {
      
      textBoxMain.Text = "";
      Filename = "";
    }

    private void menuItemOpen_Click(
      object sender, EventArgs e) {

      MyAction = Action.Open;
      NavigationService.Navigate(new Uri(
        "/PageSelectFile.xaml?msg=" + 
        "Open", UriKind.Relative));
    }

    private void menuItemSave_Click(
      object sender, EventArgs e) {
      
      if (textBoxMain.Text == "") {
        MessageBox.Show("nothing to save");
      } else {
        SaveFile(TempFilename, textBoxMain.Text);
        MyAction = Action.Save;
        NavigationService.Navigate(new Uri(
          "/PageSelectFile.xaml?msg=" + "Save", 
          UriKind.Relative));
      }
    }

    private void menuItemDelete_Click(
      object sender, EventArgs e) {
      
      SaveFile(TempFilename, textBoxMain.Text);
      MyAction = Action.Delete;
      NavigationService.Navigate(new Uri(
        "/PageSelectFile.xaml?msg=" + "Delete", 
        UriKind.Relative));
    }

    protected override void OnNavigatedTo(
      System.Windows.Navigation.NavigationEventArgs e) {

      base.OnNavigatedTo(e);
      string msg = "";
      if (NavigationContext.QueryString.
        TryGetValue("msg", out msg))
        switch (MyAction) {
          case Action.None:
            return;
          case Action.Open:
            textBoxMain.Text = LoadFile(msg);
            break;
          case Action.Save:
            SaveFile(msg, LoadFile(TempFilename));
            textBoxMain.Text = LoadFile(msg);
            break;
          case Action.Delete:
            DeleteFile(msg);
            textBoxMain.Text = LoadFile(TempFilename);
            break;
        }
    }

    private string LoadFile(string filename) {
      string s = "";
      IsolatedStorageFile isf = IsolatedStorageFile.
        GetUserStoreForApplication();
      if (isf.FileExists(filename)) {
        IsolatedStorageFileStream isfs = 
          new IsolatedStorageFileStream(
          filename, System.IO.FileMode.Open, 
          System.IO.FileAccess.Read, isf);
        using (StreamReader reader = 
          new StreamReader(isfs))
          s = reader.ReadToEnd();
        isfs.Close();
        Filename = filename;
      }
      else {
        MessageBox.Show("Cannot find " + filename);
      }
      isf.Dispose();
      return s;
    }

    private void SaveFile(string filename, 
      string content) {

      IsolatedStorageFile isf = IsolatedStorageFile.
        GetUserStoreForApplication();
      IsolatedStorageFileStream isfs = 
        new IsolatedStorageFileStream(
        filename, System.IO.FileMode.Create, 
        System.IO.FileAccess.Write, isf);

      using (StreamWriter writer = 
        new StreamWriter(isfs))
        writer.Write(content);
      Filename = filename;
      isfs.Close();
      isf.Dispose();
    }

    private void DeleteFile(string filename) {
      IsolatedStorageFile isf = 
        IsolatedStorageFile.GetUserStoreForApplication();
      if (isf.FileExists(filename)) {
        isf.DeleteFile(filename);
      } else {
        MessageBox.Show("Cannot find " + filename);
      }
      isf.Dispose();
    }

    private void menuItemVersion_Click(
      object sender, EventArgs e) {

      string s = ApplicationName +
        Environment.NewLine;
      AssemblyName an = new AssemblyName(
        Assembly.GetExecutingAssembly().FullName);
      s += "Version " + an.Version.ToString() +
        Environment.NewLine;

      object[] company =
        Assembly.GetExecutingAssembly().
        GetCustomAttributes(
        typeof(AssemblyCompanyAttribute), false);
      s += ((AssemblyCompanyAttribute)company[0]).
        Company + Environment.NewLine;
      object[] copyright = Assembly.
        GetExecutingAssembly().GetCustomAttributes(
        typeof(AssemblyCopyrightAttribute), false);
      s += ((AssemblyCopyrightAttribute)copyright[0]).
        Copyright.ToString();
      MessageBox.Show(s);
    }

    private void buttonPrevious_Click(
      object sender, EventArgs e) {

      if (textBoxMain.SelectionStart > 0)
        textBoxMain.SelectionStart -= 1;
    }

    private void buttonNext_Click(
      object sender, EventArgs e) {

      textBoxMain.SelectionStart += 1;
    }

    private void buttonKeyOnOff_Click(
      object sender, EventArgs e) { 
       
      textBoxMain.IsHitTestVisible = 
        !textBoxMain.IsHitTestVisible;
      if (textBoxMain.IsHitTestVisible) {
        textBlockKeyboardStatus.Text = "Softkey:On   ";
      } else {
        textBlockKeyboardStatus.Text = "Softkey:Off   ";
      }
    }
  }
}